@@ -63,7 +63,7 @@ public:
     ~ExerciseFactorize();
 
     /** force the creation of a new task */
-    void forceNewTask();
+    void forceNewTask() Q_DECL_OVERRIDE;
 
     void update();
 
@@ -144,7 +144,7 @@ private:
     void setButtonsEnabled(bool enabled);
 
     protected:
-    void showEvent(QShowEvent * event);
+    void showEvent(QShowEvent * event) Q_DECL_OVERRIDE;
 };
 
 #endif
